#
# Conditional build:
%bcond_with	tests		# build without tests
%bcond_without	doc		# build manual page

Summary:	Git extension for versioning large files
Name:		git-lfs
Version:	1.5.3
Release:	1
License:	MIT
Group:		Applications/Archiving
Source0:	https://github.com/github/git-lfs/archive/v%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	10c5acfaecfefd26c2e77d6747621425
URL:		https://git-lfs.github.com/
BuildRequires:	git-core
BuildRequires:	golang
BuildRequires:	groff
%{?with_doc:BuildRequires:	ronn}
Requires:	git-core >= 1.8.5
ExclusiveArch:	%{ix86} %{x8664} %{arm}
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%define		_enable_debug_packages 0
%define		import_path	github.com/git-lfs/%{name}

%ifarch %{ix86}
%define GOARCH 386
%endif
%ifarch %{x8664}
%define GOARCH amd64
%endif

%description
Git Large File Storage (LFS) replaces large files such as audio
samples, videos, datasets, and graphics with text pointers inside Git,
while storing the file contents on a remote server like GitHub.com or
GitHub Enterprise.

%prep
%setup -qc

# preserve for %doc
mv %{name}-%{version}/*.md .

install -d src/$(dirname %{import_path})
mv %{name}-%{version} src/%{import_path}

%build
unset GOROOT
export GOPATH=$(pwd)
export GOARCH=%{GOARCH}

cd src/%{import_path}
sh -x ./script/bootstrap

%if %{with doc}
./script/man
%endif

%if %{with tests}
# ensure there are no GIT env vars for testing
env | grep GIT_ && exit 3

./script/test
./script/integration
%endif

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{%{_bindir},%{_mandir}/man1}

cd src/%{import_path}
install -p bin/git-lfs $RPM_BUILD_ROOT%{_bindir}/git-lfs
%if %{with doc}
cp -p man/*.1 $RPM_BUILD_ROOT%{_mandir}/man1
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc LICENSE.md README.md ROADMAP.md CHANGELOG.md
%attr(755,root,root) %{_bindir}/git-lfs
%{?with_doc:%{_mandir}/man1/*.1*}
%changelog
* Tue Dec 27 2016 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/git-lfs.git;a=log;h=master

* Sat Dec 24 2016 Elan Ruusamäe <glen@delfi.ee> 591df62
- up to 1.5.3

* Mon Nov 28 2016 Elan Ruusamäe <glen@delfi.ee> 4cdf72e
- up to 1.5.2 (22 November, 2016)

* Tue Oct 18 2016 Elan Ruusamäe <glen@delfi.ee> a4bda40
- 1.4.3 (17 October, 2016)

* Sun Aug 28 2016 Elan Ruusamäe <glen@delfi.ee> 1bb03b0
- 1.4.1 (26 August, 2016)

* Thu Apr 07 2016 Elan Ruusamäe <glen@delfi.ee> 84475c9
- verbose build; simplify (readability)

* Thu Apr 07 2016 Elan Ruusamäe <glen@delfi.ee> 3be0973
- up to 1.1.2; fixes build problems with go 1.6

* Thu Apr 07 2016 Elan Ruusamäe <glen@delfi.ee> 61923be
- do not get affected from env from rpmbuild runs

* Wed Nov 18 2015 Elan Ruusamäe <glen@delfi.ee> 5b986cd
- BR groff

* Wed Nov 18 2015 Elan Ruusamäe <glen@delfi.ee> 2cab5a6
- test fixes, but they still fail

* Wed Nov 18 2015 Elan Ruusamäe <glen@delfi.ee> f321195
- up to 1.0.2

* Sat Oct 17 2015 Elan Ruusamäe <glen@delfi.ee> fc4d2e8
- EA same as golang

* Sat Oct 17 2015 Elan Ruusamäe <glen@delfi.ee> 42f23e2
- build man with ronn

* Fri Oct 16 2015 Elan Ruusamäe <glen@delfi.ee> 7426848
- cleanup BR, fix url

* Fri Oct 16 2015 Elan Ruusamäe <glen@delfi.ee> c5539a2
- new, version 1.0.0

